requests: An HTTP library for Python
====================================

Description
-----------

Python HTTP for Humans.

License
-------

Apache 2.0

Upstream Contact
----------------

https://pypi.org/project/requests/

